@@ -2,6 +2,9 @@ import os
 from pathlib import Path
 from shutil import copyfile
 
+from ems_config.vars import APP_DATA_DIR
+from ems_config.helpers import get_from_app_data
+
 
 def read_file(path):
     if isinstance(path, Path):
@@ -24,17 +27,28 @@ def read_file(path):
         raise ValueError(f"Unknown config extension: {path}")
 
 
-def parse_config(template="config.ini"):
-    # Get paths.
-    config_example_path = template
-    config_path = os.getenv("CONFIG_PATH", template)
+def parse_config(config_template=None, config_path=None):
+    os.makedirs(APP_DATA_DIR, exist_ok=True)
+
+    if config_template is None:
+        if "CONFIG_TEMPLATE_PATH" in os.environ:
+            config_template = os.getenv("CONFIG_TEMPLATE_PATH")
+        else:
+            config_template = "config.example.ini"
+
+    if config_path is None:
+        if "CONFIG_PATH" in os.environ:
+            config_path = os.getenv("CONFIG_PATH")
+        else:
+            template_filename = os.path.basename(config_template)
+            config_path = get_from_app_data(template_filename.replace(".example", ""))
 
     if not os.path.exists(config_path):
         dirname = os.path.dirname(config_path)
         if dirname:
             os.makedirs(dirname, exist_ok=True)
 
-        copyfile(config_example_path, config_path)
+        copyfile(config_template, config_path)
 
     cfg = read_file(config_path)
 
